package
Version:
v0.0.0-...-e5ce005
Opens a new window with list of versions in this module.
Published: Feb 4, 2023
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Voter struct {
Address string `json:"address" gorm:"primaryKey"`
PublicKey string `json:"public_key"`
Registry string `json:"registry" gorm:"uniqueIndex"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.